==> 0.6.6b1.zip: dmdirc-client/test/com/dmdirc/config/validators/URLProtocolValidatorTest.java <==
/*
 * Copyright (c) 2006-2011 DMDirc Developers
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.config.validators;

import com.dmdirc.config.IdentityManager;
import com.dmdirc.config.InvalidIdentityFileException;
import org.junit.Test;
import static org.junit.Assert.*;

public class URLProtocolValidatorTest {
    
    @Test
    public void testValidate() throws InvalidIdentityFileException {
        IdentityManager.load();
        IdentityManager.getConfigIdentity().setOption("protocol", "unit-test-1", "BROWSER");
        
        final URLProtocolValidator validator = new URLProtocolValidator();
        assertTrue(validator.validate(null).isFailure());
        assertTrue(validator.validate("").isFailure());
        assertTrue(validator.validate("unit-test-1").isFailure());
        assertFalse(validator.validate("unit-test-2").isFailure());
        
        IdentityManager.getConfigIdentity().unsetOption("protocol", "unit-test-1");
    }

}

==> 0.6.7.zip: dmdirc-client/test/com/dmdirc/config/validators/URLProtocolValidatorTest.java <==
/*
 * Copyright (c) 2006-2012 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.config.validators;

import com.dmdirc.config.IdentityManager;
import com.dmdirc.config.InvalidIdentityFileException;

import org.junit.Test;

import static org.junit.Assert.*;

public class URLProtocolValidatorTest {

    @Test
    public void testValidate() throws InvalidIdentityFileException {
        IdentityManager.getIdentityManager().initialise();
        IdentityManager.getIdentityManager().getGlobalConfigIdentity()
                .setOption("protocol", "unit-test-1", "BROWSER");

        final URLProtocolValidator validator = new URLProtocolValidator();
        assertTrue(validator.validate(null).isFailure());
        assertTrue(validator.validate("").isFailure());
        assertTrue(validator.validate("unit-test-1").isFailure());
        assertFalse(validator.validate("unit-test-2").isFailure());

        IdentityManager.getIdentityManager().getGlobalConfigIdentity()
                .unsetOption("protocol", "unit-test-1");
    }

}
